@@ -2,8 +2,8 @@
 ;; Copyright (C) 2025 Eric Dallo
 ;; Author: Eric Dallo <ercdll1337@gmail.com>
 ;; Maintainer: Eric Dallo <ercdll1337@gmail.com>
-;; Package-Version: 20260121.1245
-;; Package-Revision: 298849d1aae3
+;; Package-Version: 20260209.1756
+;; Package-Revision: 9a6f6fc43d31
 ;; Package-Requires: ((emacs "28.1") (dash "2.18.0") (f "0.20.0") (markdown-mode "2.3") (compat "30.1"))
 ;; Keywords: tools
 ;; Homepage: https://github.com/editor-code-assistant/eca-emacs
@@ -155,7 +155,7 @@
                                    :version (emacs-version))
                  :capabilities (list :codeAssistant (list :chat t
                                                           :editor (list :diagnostics t)))
-                 :initializationOptions (list :chatBehavior eca-chat-custom-behavior)
+                 :initializationOptions (list :chatAgent eca-chat-custom-agent)
                  :workspaceFolders (vconcat (-map (lambda (folder)
                                                     (list :uri (eca--path-to-uri folder)
                                                           :name (file-name-nondirectory (directory-file-name folder))))
